summaryrefslogtreecommitdiff
path: root/print/hplip3/files/patch-cups.py
blob: a04535bff76af83304af0f04f3b0645ed204bcf8 (plain) (blame)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
--- prnt/cups.py.bak	2009-07-31 05:28:04.000000000 -0500
+++ prnt/cups.py	2009-07-31 05:29:26.000000000 -0500
@@ -202,9 +202,9 @@
 
 def getAllowableMIMETypes():
     """
         Scan all /etc/cups/*.convs files for allowable file formats.
     """
-    files = glob.glob("/etc/cups/*.convs")
+    files = glob.glob("/usr/local/etc/cups/*.convs")
 
     allowable_mime_types = []
 
@@ -527,7 +527,7 @@
 
 
 def getErrorLogLevel():
-    cups_conf = '/etc/cups/cupsd.conf'
+    cups_conf = '/usr/local/etc/cups/cupsd.conf'
     try:
         f = file(cups_conf, 'r')
     except OSError:
@@ -202,9 +202,9 @@
 def getAllowableMIMETypes():
     """
-        Scan all /etc/cups/*.convs files for allowable file formats.
+        Scan all /usr/local/etc/cups/*.convs files for allowable file formats.
     """